@@ -1,6 +1,6 @@
 #!/usr/bin/python
-# $Id: trapsender.py 47 2008-09-25 05:07:01Z daedalus $
-# $Revision: 47 $
+# $Id: trapsender.py 57 2010-01-29 23:45:50Z daedalus $
+# $Revision: 57 $
 #
 #    libsnmp - a Python SNMP library
 #    Copyright (c) 2003 Justin Warren <daedalus@eigenmagic.com>
@@ -22,9 +22,10 @@ from libsnmp import v2
 
 import time
 
-sleeptime = 1
+sleeptime = 5
 microsleep = 0.1
-
+endafter = 0
+finishat = time.time() + endafter
 lasttime = 0
 
 ##
@@ -43,12 +44,15 @@ def whenDone(snmpClient):
     varbindlist = rfc1157.VarBindList( [ varbind ] )
 #    print 'varbindlist: %s' % varbindlist
 
-    trapPDU = snmpClient.createTrapPDU( varbindlist )
+    trapPDU = snmpClient.createTrap( varbindlist )
 #    print('pdu: %s' % trapPDU)
 
 ## Send to SNMP trap port.
     snmpClient.snmpTrap( ('localhost', 162), trapPDU )
 
+    if finishat > 0 and lasttime > finishat:
+        sys.exit(0)
+
 # Main bits
 
 # Read command line
